@@ -10,6 +10,7 @@
 #include <pi-dlp.h>
 #include <pi-version.h>
 
+#include <errno.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <utime.h>
@@ -244,6 +245,7 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
         int i;
         int ret;
         int filehandle[17];
+        int result = 0;
 
         if(GET_CONDUIT_CFG(c)->dir==NULL) {
 		g_warning(_("No dir specified. Please run expense conduit capplet first."));
@@ -294,8 +296,10 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
         /* make the directory */
         if(mkdir(GET_CONDUIT_CFG(c)->dir, GET_CONDUIT_CFG(c)->dirMode) < 0) {
                 if(errno != EEXIST) {
-                        g_warning ("Unable to create directory:\n\t%s\n", GET_CONDUIT_CFG(c)->dir);
-                        return -1;
+                        g_warning ("Unable to create directory:\n\t%s\n\t%s\n", 
+                                   GET_CONDUIT_CFG(c)->dir,
+                                   strerror (errno));
+                        goto error;
                 }
         }
         
@@ -306,7 +310,7 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
                         if((filehandle[i] = creat(category_path(i, c), GET_CONDUIT_CFG(c)->fileMode))== -1) {
                                 LOG("copy_from_pilot: error in opening %s", category_path(i, c));
                                 perror("");
-                                return -1;
+                                goto error;
                         }
                 } else {
                         filehandle[i] = -1;
@@ -332,16 +336,19 @@ static gint copy_from_pilot( GnomePilotConduit *c, GnomePilotDBInfo *dbi )
                 free_Expense(&t);
         }
 
+        goto exit;
+ error:
+        result = -1;
+ exit:
         /* close all the opened filehandles */
         for(i = 0; i < 17; i++)
                 if(filehandle[i] != -1)
                         close(filehandle[i]);
-        
-        dlp_ResetLastSyncPC( dbi->pilot_socket );
+
         /* Close the database */
         dlp_CloseDB(dbi->pilot_socket, dbHandle);
         
-        return( 0 );
+        return( result );
 }
 
 static gint synchronize( GnomePilotConduit *c, GnomePilotDBInfo *dbi ) {
