@@ -33,6 +33,7 @@
  */
 #include <stdio.h>
 #include <signal.h>
+#include <fcntl.h>
 
 #ifdef _WIN32
 /* Fucking windows doesn't have getopt? */
@@ -67,18 +68,21 @@
 #include <pi-dlp.h>
 #include <pi-version.h>
 
+#include <gpilotd/gnome-pilot-conduit.h>
+extern GnomePilotConduit *the_conduit;
+
 #define DEFAULT_CARD_NUM 0
 
 #define VERSION_STRING "malsync version 2.0.4"
 
 static void Connect();
 static char *device = "/dev/pilot";
-static char *httpProxy      = NULL;
-static int   httpProxyPort  = 0;
-static char *socksProxy     = NULL;
-static int   socksProxyPort = 0;
-static char *proxyUsername  = NULL;
-static char *proxyPassword  = NULL;
+char *httpProxy      = NULL;
+int   httpProxyPort  = 0;
+char *socksProxy     = NULL;
+int   socksProxyPort = 0;
+char *proxyUsername  = NULL;
+char *proxyPassword  = NULL;
 static char *progname       = NULL;
 #ifdef _DEBUG
 #define debug_print(x) printf("%s\n", (x));
@@ -133,7 +137,7 @@ static struct option long_options[] =
 #endif
 
 int sd = 0;
-static int verbose = 0;
+static int verbose;
 static int daemon_mode = 0;
 static int threeone = 0;
 static int lowres = 0;
@@ -145,9 +149,9 @@ static int32 getNextModifiedRecord(void * out, AGRecord ** record,
 static int32 getNextRecord(void * out, AGRecord ** record,
                            int32 *errCode);
 
-static int32 cmdTASK(void *out, int32 *returnErrorCode, char *currentTask,
+extern int32 cmdTASK(void *out, int32 *returnErrorCode, char *currentTask,
                      AGBool bufferable);
-static int32 cmdITEM(void *out, int32 *returnErrorCode,
+extern int32 cmdITEM(void *out, int32 *returnErrorCode,
                                    int32 currentItemNumber,
                                    int32 totalItemCount,
                                    char *currentItem);
@@ -632,6 +636,7 @@ static long openUserConfigDatabase(int *threeone)
         result = dlp_OpenDB(sd, DEFAULT_CARD_NUM, dlpOpenRead|dlpOpenWrite,  
                             DEVICE_USERCONFIG_DB_NAME, 
                             &userConfigDBHandle);
+
         if (result < 0) {
             
             result = dlp_CreateDB(sd, DEVICE_PROFILE_DB_CREATOR, 
@@ -639,7 +644,7 @@ static long openUserConfigDatabase(int *threeone)
                                   0, 0, DEVICE_PROFILE_DB_NAME, 
                                   &userConfigDBHandle);
             if (result < 0) {
-                fprintf(stderr, "Unable to create user Config Databage\n");
+                fprintf(stderr, "Unable to create user Config Databage, %s\n", dlp_strerror (result));
                 userConfigDBHandle = 0;
             }        
         } else {
@@ -779,7 +784,9 @@ AGUserConfig *getUserConfig(uint32 * pilotID)
     userConfigDBHandle = openUserConfigDatabase(&threeone);
 
     if (userConfigDBHandle) {
-        
+        if (verbose) {
+            fprintf (stderr, "Reading user config...\n");
+        }
         
         /* Retrieve device's idea of current userConfig. */
         *pilotID = readDeviceUserConfig(userConfigDBHandle,
@@ -790,6 +797,10 @@ AGUserConfig *getUserConfig(uint32 * pilotID)
         dlp_CloseDB(sd, userConfigDBHandle);
         
 
+    } else {
+        if (verbose) {
+            fprintf (stderr, "No user config, haha...\n");
+        }
     }
     return deviceUserConfig;
 }
@@ -847,8 +858,10 @@ doEndServer(PalmSyncInfo * pInfo, int32 *errCode)
         pInfo->commandProcessor = NULL;
     }
 }
+
+#if 0
 /*---------------------------------------------------------------------------*/
-static int32 
+int32 
 cmdTASK(void *out, int32 *returnErrorCode, char *currentTask, 
         AGBool bufferable)
 {
@@ -857,7 +870,7 @@ cmdTASK(void *out, int32 *returnErrorCode, char *currentTask,
     return AGCLIENT_CONTINUE;
 }
 /*---------------------------------------------------------------------------*/
-static int32 
+int32 
 cmdITEM(void *out, int32 *returnErrorCode, int32 currentItemNumber,
         int32 totalItemCount, char *currentItem)
 {
@@ -868,6 +881,8 @@ cmdITEM(void *out, int32 *returnErrorCode, int32 currentItemNumber,
     
     return AGCLIENT_CONTINUE;
 }
+#endif 
+
 /*---------------------------------------------------------------------------*/
 static int32 
 cmdDELETEDATABASE(void *out, int32 *returnErrorCode, char *dbname)
@@ -928,7 +943,7 @@ cmdGOODBYE(void *out, int32 *returnErrorCode, AGSyncStatus syncStatus,
         printf("doCmdAG_GOODBYE_CMD()\n");
 
     if (errorMessage)
-        printf("%s\n", errorMessage);
+        printf("MALsync %s\n", errorMessage);
     
     return AGCLIENT_CONTINUE;
 }
@@ -1230,7 +1245,6 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
             
             AGClientProcessorSync(pInfo->clientProcessor);
 
-
             cpResult = AGCLIENT_CONTINUE;
             while (AGCLIENT_CONTINUE == cpResult) {
                 cpResult = AGClientProcessorProcess(pInfo->clientProcessor);
@@ -1242,7 +1256,7 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
                 if (dlp_OpenConduit(sd)<0) {
                     fprintf(stderr, 
                             "Exiting on cancel, data not retrieved.\n");
-                    exit(1);
+                    cancelled = TRUE;
                 }
                 
             }
@@ -1251,10 +1265,13 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
             if(cpResult == AGCLIENT_ERR) {
 
                 char *msg = AGGetMsg(pInfo->clientProcessor->errStringId);
-                if (msg)
-                    fprintf(stderr,"%s\n", msg);
-                else
+                if (msg) {
+                    gnome_pilot_conduit_send_message (the_conduit, msg);
+                    fprintf(stderr,"MALsync message %s\n", msg);
+                } else {
+                    gnome_pilot_conduit_send_message (the_conduit, msg);
                     fprintf(stderr,"Unknown error\n");
+                }
                     
             }
 
@@ -1277,6 +1294,8 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
         
     }
 
+    fprintf (stderr, "cancelled = %s, verbose = %d\n", cancelled ? "true" : "false", verbose);
+
     return TRUE; /* success */
 }
 /*---------------------------------------------------------------------------*/
